@@ -10,6 +10,7 @@
 #include "fbd-feedback-profile.h"
 #include "fbd-feedback-sound.h"
 #include "fbd-feedback-led.h"
+#include "fbd-feedback-vibra-pattern.h"
 #include "fbd-feedback-vibra-periodic.h"
 #include "fbd-feedback-vibra-rumble.h"
 
@@ -85,6 +86,7 @@ feedback_get_type (JsonNode *feedback_node)
   /* Ensure all feedback types so the json parsing can use them */
   g_type_ensure (FBD_TYPE_FEEDBACK_DUMMY);
   g_type_ensure (FBD_TYPE_FEEDBACK_LED);
+  g_type_ensure (FBD_TYPE_FEEDBACK_VIBRA_PATTERN);
   g_type_ensure (FBD_TYPE_FEEDBACK_VIBRA_PERIODIC);
   g_type_ensure (FBD_TYPE_FEEDBACK_VIBRA_RUMBLE);
   g_type_ensure (FBD_TYPE_FEEDBACK_SOUND);
