@@ -24,6 +24,7 @@ enum {
   PROP_0,
   PROP_EFFECT,
   PROP_FILE_NAME,
+  PROP_MEDIA_ROLE,
   PROP_LAST_PROP,
 };
 static GParamSpec *props[PROP_LAST_PROP];
@@ -33,6 +34,7 @@ typedef struct _FbdFeedbackSound {
 
   char           *effect;
   char           *file_name;
+  char           *media_role;
 } FbdFeedbackSound;
 
 G_DEFINE_TYPE (FbdFeedbackSound, fbd_feedback_sound, FBD_TYPE_FEEDBACK_BASE);
@@ -91,6 +93,9 @@ fbd_feedback_sound_set_property (GObject      *object,
   case PROP_FILE_NAME:
     self->file_name = g_value_dup_string (value);
     break;
+  case PROP_MEDIA_ROLE:
+    self->media_role = g_value_dup_string (value);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     break;
@@ -112,6 +117,9 @@ fbd_feedback_sound_get_property (GObject    *object,
   case PROP_FILE_NAME:
     g_value_set_string (value, fbd_feedback_sound_get_file_name (self));
     break;
+  case PROP_MEDIA_ROLE:
+    g_value_set_string (value, fbd_feedback_sound_get_media_role (self));
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     break;
@@ -125,6 +133,7 @@ fbd_feedback_sound_finalize (GObject *object)
 
   g_clear_pointer (&self->effect, g_free);
   g_clear_pointer (&self->file_name, g_free);
+  g_clear_pointer (&self->media_role, g_free);
 
   G_OBJECT_CLASS (fbd_feedback_sound_parent_class)->finalize (object);
 }
@@ -143,18 +152,34 @@ fbd_feedback_sound_class_init (FbdFeedbackSoundClass *klass)
   base_class->end = fbd_feedback_sound_end;
   base_class->is_available = fbd_feedback_sound_is_available;
 
+  /**
+   * FbdFeedbackSound:effect:
+   *
+   * The sound effect name
+   */
   props[PROP_EFFECT] =
-    g_param_spec_string (
-      "effect",
-      "Effect",
-      "The sound effects name",
-      "",
-      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
-
+    g_param_spec_string ("effect", "", "",
+                         NULL,
+                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+  /**
+   * FbdFeedbackSound:file-name:
+   *
+   * The file name to use for the sound effect. This overrides the
+   * effect name.
+   */
   props[PROP_FILE_NAME] =
     g_param_spec_string ("file-name", "", "",
                          NULL,
                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+  /**
+   * FbdFeedbackSound:media-role:
+   *
+   * The media-role to use when playing the sound.
+   */
+  props[PROP_MEDIA_ROLE] =
+    g_param_spec_string ("media-role", "", "",
+                         NULL,
+                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, PROP_LAST_PROP, props);
 }
@@ -178,8 +203,16 @@ fbd_feedback_sound_get_effect (FbdFeedbackSound *self)
   return self->effect;
 }
 
+
 const char *
 fbd_feedback_sound_get_file_name (FbdFeedbackSound *self)
 {
   return self->file_name;
 }
+
+
+const char *
+fbd_feedback_sound_get_media_role (FbdFeedbackSound *self)
+{
+  return self->media_role;
+}
