@@ -159,6 +159,35 @@ test_fbd_dev_led_qcom_multicolor (FbdUmockdevFixture *fixture, gconstpointer unu
 }
 
 
+static void
+test_fbd_dev_led_legacy (FbdUmockdevFixture *fixture, gconstpointer unused)
+{
+  GUdevClient *client;
+  g_autolist (GUdevDevice) leds = NULL;
+  FbdDevLed *led;
+  g_autoptr (GError) err = NULL;
+  GUdevDevice *dev;
+
+  client = g_udev_client_new ((const char *const []){ "leds", NULL});
+  leds = g_udev_client_query_by_subsystem (client, "leds");
+
+  /* There should be a single device only */
+  g_assert_cmpint (g_list_length (leds), ==, 1);
+  dev = G_UDEV_DEVICE (leds->data);
+
+  g_assert_cmpstr (g_udev_device_get_property (dev, "FEEDBACKD_TYPE"), ==, "led");
+  g_assert_cmpstr (g_udev_device_get_property (dev, "FEEDBACKD_LED_COLOR"), ==, "red");
+
+  led = fbd_dev_led_new (dev, &err);
+  g_assert_no_error (err);
+  g_assert_cmpint (fbd_dev_led_get_max_brightness (led), ==, 255);
+  g_assert_cmpint (fbd_dev_led_get_priority (led), ==, 10);
+  g_assert_true (fbd_dev_led_supports_color (led, FBD_FEEDBACK_LED_COLOR_RED));
+  g_assert_true (fbd_dev_led_start_periodic (led, 50, 50));
+  g_assert_finalize_object (led);
+}
+
+
 gint
 main (gint argc, gchar *argv[])
 {
@@ -179,6 +208,9 @@ main (gint argc, gchar *argv[])
   FBD_UMOCKDEV_TEST_ADD ("/feedbackd/fbd/dev/led/qcom/multicolor",
                          test_fbd_dev_led_qcom_multicolor,
                          "led-qcom-multicolor");
+  FBD_UMOCKDEV_TEST_ADD ("/feedbackd/fbd/dev/led/legacy",
+                         test_fbd_dev_led_legacy,
+                         "led-legacy");
 
   return g_test_run();
 }
